library(tidyverse) # Data Wrangling and Visualization
library(lubridate) # Date Manipulation
library(readr)
results <- read_csv("arman/poisson in R/fifa result.zip")
#View(results)
results = results %>% 
  mutate(year = as.factor(year(date)),
         month = as.factor(month(date)),
         totalGoals = home_score + away_score,
         tournament = as.factor(tournament))
results %>% 
  group_by(year) %>% 
  summarise(mean(totalGoals), sum(totalGoals), min(totalGoals), max(totalGoals), median(totalGoals))
results %>% 
  group_by(year) %>% 
  summarise(meanGoals = mean(totalGoals)) %>% 
  ggplot(aes(x=year, y=meanGoals)) + 
  geom_col(fill = "purple") +
  labs(x = "سال", y = "میانگین",
       title = "میانگین کل گل ها برای هر سال",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank())

results %>% 
  group_by(year) %>% 
  summarise(numGoals = sum(totalGoals)) %>% 
  ggplot(aes(x=year, y=numGoals)) + 
  geom_col(fill = "blue") +
  labs(x = "سال", y = " گل های زده شده",
       title = "مجموع گل های زده شده به تفکیک سال",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank())

results %>% 
  group_by(date) %>% 
  summarise(numGoals = sum(totalGoals), numMatches = n()) %>% 
  ggplot(aes(x = numMatches, y = numGoals)) + 
  geom_point(color = "green") +
  geom_smooth(se=FALSE) + 
  labs(x = "تعداد مسابقات در روز",
       y = "تعداد گل های زده شده در هر روز",
       title = "مقایسه تعداد بازی در مقابل تعداد گل زده",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"))

results %>% 
  group_by(date) %>% 
  summarise(numGoals = sum(totalGoals)) %>% 
  ggplot(aes(x=date, y=numGoals)) + 
  geom_col(fill = "blue") +
  labs(x = "روز", 
       y = "کل گل های زده شده",
       title = "تعداد کل گل های زده شده در هر روز",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank())

results %>% 
  ggplot(aes(totalGoals)) + 
  geom_histogram(fill = "blue", binwidth = 1) +
  labs(x = "دسته (طول=1)",
       y = "گل های زده شده در هر مسابقه",
       title = "نمودار فراوانی - هیستوگرام برای تعداد گل های زده شده در هر مسابقه",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"))

tibble(x=0:8, px=dpois(0:8, lambda = mean(results$totalGoals))) %>% 
  ggplot(aes(x=x, y=px)) + 
  geom_smooth(se=FALSE) +
  coord_cartesian(xlim = c(0,8)) +
  labs(x = "تعداد گل ها"
       , y= "احتمال",
       title = "احتمال تعداد گل های زده در یک مسابقه",
       caption = "Data Source: https://www.kaggle.com/martj42/international-football-results-from-1872-to-2017") + 
  theme(panel.background = element_blank(),
        panel.grid.minor = element_line(colour = "grey"))
